@@ -4,7 +4,7 @@ use Mojo::Base -base;
 use Encode;
 use Role::Tiny;
 
-our $VERSION = '1.001001'; # VERSION
+our $VERSION = '1.001002'; # VERSION
 
 has _counter_selector_prefix => '';
 
@@ -63,7 +63,7 @@ __END__
 
 =encoding utf8
 
-=for stopwords Znet Zoffix app
+=for stopwords Znet Zoffix app  natively
 
 =head1 NAME
 
@@ -113,7 +113,7 @@ The test we write:
             ->dived_text_is('a[href="/product/2"]' => 'Product 2')
             ->dived_text_is('a[href="/product/3"]' => 'Product 3')
         ->dive_out('> ul')
-        ->element_count_is('+ li + li a', 1);
+        ->element_count_is('+ li a', 1);
     ->dive_reset
     ->element_count_is('#products + p', 1)
     ->text_is('#products + p' => 'Select a product!')
@@ -122,6 +122,13 @@ The test we write:
 
 =for html  </div></div>
 
+=head1 SEE ALSO
+
+Note that as of L<Mojolicious> version 6.06,
+L<Test::Mojo> implements the exact match
+version of C<element_count_is> natively (same method name).
+This role is helpful only if you need dive methods or ranges.
+
 =head1 DESCRIPTION
 
 A L<Test::Mojo> role that allows you to do strict element count tests on
